import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Datadog Application Key resource. This can be used to create and manage Datadog Application Keys.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * // Create a new Datadog Application Key
 * const foo = new datadog.ApplicationKey("foo", {name: "foo-application"});
 * ```
 *
 * ## Import
 *
 * ```sh
 *  $ pulumi import datadog:index/applicationKey:ApplicationKey foo 11111111-2222-3333-4444-555555555555
 * ```
 */
export declare class ApplicationKey extends pulumi.CustomResource {
    /**
     * Get an existing ApplicationKey resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ApplicationKeyState, opts?: pulumi.CustomResourceOptions): ApplicationKey;
    /**
     * Returns true if the given object is an instance of ApplicationKey.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ApplicationKey;
    /**
     * The value of the Application Key.
     */
    readonly key: pulumi.Output<string>;
    /**
     * Name for Application Key.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Create a ApplicationKey resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ApplicationKeyArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ApplicationKey resources.
 */
export interface ApplicationKeyState {
    /**
     * The value of the Application Key.
     */
    key?: pulumi.Input<string>;
    /**
     * Name for Application Key.
     */
    name?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ApplicationKey resource.
 */
export interface ApplicationKeyArgs {
    /**
     * Name for Application Key.
     */
    name: pulumi.Input<string>;
}
