import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Datadog AuthN Mappings resource. This feature lets you automatically assign roles to users based on their SAML attributes.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const roRole = datadog.getRole({
 *     filter: "Datadog Read Only Role",
 * });
 * // Create a new AuthN mapping
 * const devRoRoleMapping = new datadog.AuthnMapping("devRoRoleMapping", {
 *     key: "Member-of",
 *     value: "Development",
 *     role: roRole.then(roRole => roRole.id),
 * });
 * ```
 *
 * ## Import
 *
 * AuthN mappings can be imported using their ID, e.g.
 *
 * ```sh
 *  $ pulumi import datadog:index/authnMapping:AuthnMapping dev_ro_mapping 000000-0000-0000-0000-000000000000
 * ```
 */
export declare class AuthnMapping extends pulumi.CustomResource {
    /**
     * Get an existing AuthnMapping resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: AuthnMappingState, opts?: pulumi.CustomResourceOptions): AuthnMapping;
    /**
     * Returns true if the given object is an instance of AuthnMapping.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AuthnMapping;
    /**
     * Identity provider key.
     */
    readonly key: pulumi.Output<string>;
    /**
     * The ID of a role to attach to all users with the corresponding key and value.
     */
    readonly role: pulumi.Output<string>;
    /**
     * Identity provider value.
     */
    readonly value: pulumi.Output<string>;
    /**
     * Create a AuthnMapping resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AuthnMappingArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering AuthnMapping resources.
 */
export interface AuthnMappingState {
    /**
     * Identity provider key.
     */
    key?: pulumi.Input<string>;
    /**
     * The ID of a role to attach to all users with the corresponding key and value.
     */
    role?: pulumi.Input<string>;
    /**
     * Identity provider value.
     */
    value?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a AuthnMapping resource.
 */
export interface AuthnMappingArgs {
    /**
     * Identity provider key.
     */
    key: pulumi.Input<string>;
    /**
     * The ID of a role to attach to all users with the corresponding key and value.
     */
    role: pulumi.Input<string>;
    /**
     * Identity provider value.
     */
    value: pulumi.Input<string>;
}
