import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Datadog - Amazon Web Services integration Lambda ARN resource. This can be used to create and manage the log collection Lambdas for an account.
 *
 * Update operations are currently not supported with datadog API so any change forces a new resource.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * // Create a new Datadog - Amazon Web Services integration Lambda ARN
 * const mainCollector = new datadog.aws.IntegrationLambdaArn("mainCollector", {
 *     accountId: "1234567890",
 *     lambdaArn: "arn:aws:lambda:us-east-1:1234567890:function:datadog-forwarder-Forwarder",
 * });
 * ```
 *
 * ## Import
 *
 * Amazon Web Services Lambda ARN integrations can be imported using their account_id and lambda_arn separated with a space (` `).
 *
 * ```sh
 *  $ pulumi import datadog:aws/integrationLambdaArn:IntegrationLambdaArn test "1234567890 arn:aws:lambda:us-east-1:1234567890:function:datadog-forwarder-Forwarder"
 * ```
 */
export declare class IntegrationLambdaArn extends pulumi.CustomResource {
    /**
     * Get an existing IntegrationLambdaArn resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: IntegrationLambdaArnState, opts?: pulumi.CustomResourceOptions): IntegrationLambdaArn;
    /**
     * Returns true if the given object is an instance of IntegrationLambdaArn.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is IntegrationLambdaArn;
    /**
     * Your AWS Account ID without dashes. If your account is a GovCloud or China account, specify the `accessKeyId` here.
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * The ARN of the Datadog forwarder Lambda.
     */
    readonly lambdaArn: pulumi.Output<string>;
    /**
     * Create a IntegrationLambdaArn resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IntegrationLambdaArnArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering IntegrationLambdaArn resources.
 */
export interface IntegrationLambdaArnState {
    /**
     * Your AWS Account ID without dashes. If your account is a GovCloud or China account, specify the `accessKeyId` here.
     */
    accountId?: pulumi.Input<string>;
    /**
     * The ARN of the Datadog forwarder Lambda.
     */
    lambdaArn?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a IntegrationLambdaArn resource.
 */
export interface IntegrationLambdaArnArgs {
    /**
     * Your AWS Account ID without dashes. If your account is a GovCloud or China account, specify the `accessKeyId` here.
     */
    accountId: pulumi.Input<string>;
    /**
     * The ARN of the Datadog forwarder Lambda.
     */
    lambdaArn: pulumi.Input<string>;
}
