import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Datadog - Amazon Web Services integration log collection resource. This can be used to manage which AWS services logs are collected from for an account.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * // Create a new Datadog - Amazon Web Services integration log collection
 * const main = new datadog.aws.IntegrationLogCollection("main", {
 *     accountId: "1234567890",
 *     services: ["lambda"],
 * });
 * ```
 *
 * ## Import
 *
 * Amazon Web Services log collection integrations can be imported using the `account ID`.
 *
 * ```sh
 *  $ pulumi import datadog:aws/integrationLogCollection:IntegrationLogCollection test 1234567890
 * ```
 */
export declare class IntegrationLogCollection extends pulumi.CustomResource {
    /**
     * Get an existing IntegrationLogCollection resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: IntegrationLogCollectionState, opts?: pulumi.CustomResourceOptions): IntegrationLogCollection;
    /**
     * Returns true if the given object is an instance of IntegrationLogCollection.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is IntegrationLogCollection;
    /**
     * Your AWS Account ID without dashes. If your account is a GovCloud or China account, specify the `accessKeyId` here.
     */
    readonly accountId: pulumi.Output<string>;
    /**
     * A list of services to collect logs from. See the [api docs](https://docs.datadoghq.com/api/v1/aws-logs-integration/#get-list-of-aws-log-ready-services) for more details on which services are supported.
     */
    readonly services: pulumi.Output<string[]>;
    /**
     * Create a IntegrationLogCollection resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IntegrationLogCollectionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering IntegrationLogCollection resources.
 */
export interface IntegrationLogCollectionState {
    /**
     * Your AWS Account ID without dashes. If your account is a GovCloud or China account, specify the `accessKeyId` here.
     */
    accountId?: pulumi.Input<string>;
    /**
     * A list of services to collect logs from. See the [api docs](https://docs.datadoghq.com/api/v1/aws-logs-integration/#get-list-of-aws-log-ready-services) for more details on which services are supported.
     */
    services?: pulumi.Input<pulumi.Input<string>[]>;
}
/**
 * The set of arguments for constructing a IntegrationLogCollection resource.
 */
export interface IntegrationLogCollectionArgs {
    /**
     * Your AWS Account ID without dashes. If your account is a GovCloud or China account, specify the `accessKeyId` here.
     */
    accountId: pulumi.Input<string>;
    /**
     * A list of services to collect logs from. See the [api docs](https://docs.datadoghq.com/api/v1/aws-logs-integration/#get-list-of-aws-log-ready-services) for more details on which services are supported.
     */
    services: pulumi.Input<pulumi.Input<string>[]>;
}
