import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Datadog Cloud Workload Security Agent Rule API resource for agent rules.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const myAgentRule = new datadog.CloudWorkloadSecurityAgentRule("myAgentRule", {
 *     description: "My agent rule",
 *     enabled: true,
 *     expression: "exec.file.name == \"java\"",
 *     name: "my_agent_rule",
 * });
 * ```
 *
 * ## Import
 *
 * Cloud Workload Security Agent rules can be imported using ID, e.g.
 *
 * ```sh
 *  $ pulumi import datadog:index/cloudWorkloadSecurityAgentRule:CloudWorkloadSecurityAgentRule my_agent_rule m0o-hto-lkb
 * ```
 */
export declare class CloudWorkloadSecurityAgentRule extends pulumi.CustomResource {
    /**
     * Get an existing CloudWorkloadSecurityAgentRule resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: CloudWorkloadSecurityAgentRuleState, opts?: pulumi.CustomResourceOptions): CloudWorkloadSecurityAgentRule;
    /**
     * Returns true if the given object is an instance of CloudWorkloadSecurityAgentRule.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CloudWorkloadSecurityAgentRule;
    /**
     * The description of the Agent rule.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Whether the Agent rule is enabled.
     */
    readonly enabled: pulumi.Output<boolean | undefined>;
    /**
     * The SECL expression of the Agent rule.
     */
    readonly expression: pulumi.Output<string>;
    /**
     * The name of the Agent rule.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Create a CloudWorkloadSecurityAgentRule resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CloudWorkloadSecurityAgentRuleArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering CloudWorkloadSecurityAgentRule resources.
 */
export interface CloudWorkloadSecurityAgentRuleState {
    /**
     * The description of the Agent rule.
     */
    description?: pulumi.Input<string>;
    /**
     * Whether the Agent rule is enabled.
     */
    enabled?: pulumi.Input<boolean>;
    /**
     * The SECL expression of the Agent rule.
     */
    expression?: pulumi.Input<string>;
    /**
     * The name of the Agent rule.
     */
    name?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a CloudWorkloadSecurityAgentRule resource.
 */
export interface CloudWorkloadSecurityAgentRuleArgs {
    /**
     * The description of the Agent rule.
     */
    description?: pulumi.Input<string>;
    /**
     * Whether the Agent rule is enabled.
     */
    enabled?: pulumi.Input<boolean>;
    /**
     * The SECL expression of the Agent rule.
     */
    expression: pulumi.Input<string>;
    /**
     * The name of the Agent rule.
     */
    name: pulumi.Input<string>;
}
