import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Provides a Datadog dashboard resource. This can be used to create and manage Datadog dashboards.
 *
 * ## Import
 *
 * ```sh
 *  $ pulumi import datadog:index/dashboard:Dashboard my_service_dashboard sv7-gyh-kas
 * ```
 */
export declare class Dashboard extends pulumi.CustomResource {
    /**
     * Get an existing Dashboard resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: DashboardState, opts?: pulumi.CustomResourceOptions): Dashboard;
    /**
     * Returns true if the given object is an instance of Dashboard.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Dashboard;
    /**
     * A list of dashboard lists this dashboard belongs to.
     */
    readonly dashboardLists: pulumi.Output<number[] | undefined>;
    /**
     * A list of dashboard lists this dashboard should be removed from. Internal only.
     */
    readonly dashboardListsRemoveds: pulumi.Output<number[]>;
    /**
     * The description of the dashboard.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Whether this dashboard is read-only. **Deprecated.** Prefer using `restrictedRoles` to define which roles are required to edit the dashboard.
     *
     * @deprecated Prefer using `restricted_roles` to define which roles are required to edit the dashboard.
     */
    readonly isReadOnly: pulumi.Output<boolean | undefined>;
    /**
     * The layout type of the dashboard. Valid values are `ordered`, `free`.
     */
    readonly layoutType: pulumi.Output<string>;
    /**
     * The list of handles for the users to notify when changes are made to this dashboard.
     */
    readonly notifyLists: pulumi.Output<string[] | undefined>;
    /**
     * The reflow type of a new dashboard layout. Set this only when layout type is `ordered`. If set to `fixed`, the dashboard expects all widgets to have a layout, and if it's set to `auto`, widgets should not have layouts. Valid values are `auto`, `fixed`.
     */
    readonly reflowType: pulumi.Output<string | undefined>;
    /**
     * UUIDs of roles whose associated users are authorized to edit the dashboard.
     */
    readonly restrictedRoles: pulumi.Output<string[] | undefined>;
    /**
     * The list of selectable template variable presets for this dashboard.
     */
    readonly templateVariablePresets: pulumi.Output<outputs.DashboardTemplateVariablePreset[] | undefined>;
    /**
     * The list of template variables for this dashboard.
     */
    readonly templateVariables: pulumi.Output<outputs.DashboardTemplateVariable[] | undefined>;
    /**
     * The title of the dashboard.
     */
    readonly title: pulumi.Output<string>;
    /**
     * The URL of the dashboard.
     */
    readonly url: pulumi.Output<string>;
    /**
     * The list of widgets to display on the dashboard.
     */
    readonly widgets: pulumi.Output<outputs.DashboardWidget[] | undefined>;
    /**
     * Create a Dashboard resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DashboardArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Dashboard resources.
 */
export interface DashboardState {
    /**
     * A list of dashboard lists this dashboard belongs to.
     */
    dashboardLists?: pulumi.Input<pulumi.Input<number>[]>;
    /**
     * A list of dashboard lists this dashboard should be removed from. Internal only.
     */
    dashboardListsRemoveds?: pulumi.Input<pulumi.Input<number>[]>;
    /**
     * The description of the dashboard.
     */
    description?: pulumi.Input<string>;
    /**
     * Whether this dashboard is read-only. **Deprecated.** Prefer using `restrictedRoles` to define which roles are required to edit the dashboard.
     *
     * @deprecated Prefer using `restricted_roles` to define which roles are required to edit the dashboard.
     */
    isReadOnly?: pulumi.Input<boolean>;
    /**
     * The layout type of the dashboard. Valid values are `ordered`, `free`.
     */
    layoutType?: pulumi.Input<string>;
    /**
     * The list of handles for the users to notify when changes are made to this dashboard.
     */
    notifyLists?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The reflow type of a new dashboard layout. Set this only when layout type is `ordered`. If set to `fixed`, the dashboard expects all widgets to have a layout, and if it's set to `auto`, widgets should not have layouts. Valid values are `auto`, `fixed`.
     */
    reflowType?: pulumi.Input<string>;
    /**
     * UUIDs of roles whose associated users are authorized to edit the dashboard.
     */
    restrictedRoles?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The list of selectable template variable presets for this dashboard.
     */
    templateVariablePresets?: pulumi.Input<pulumi.Input<inputs.DashboardTemplateVariablePreset>[]>;
    /**
     * The list of template variables for this dashboard.
     */
    templateVariables?: pulumi.Input<pulumi.Input<inputs.DashboardTemplateVariable>[]>;
    /**
     * The title of the dashboard.
     */
    title?: pulumi.Input<string>;
    /**
     * The URL of the dashboard.
     */
    url?: pulumi.Input<string>;
    /**
     * The list of widgets to display on the dashboard.
     */
    widgets?: pulumi.Input<pulumi.Input<inputs.DashboardWidget>[]>;
}
/**
 * The set of arguments for constructing a Dashboard resource.
 */
export interface DashboardArgs {
    /**
     * A list of dashboard lists this dashboard belongs to.
     */
    dashboardLists?: pulumi.Input<pulumi.Input<number>[]>;
    /**
     * The description of the dashboard.
     */
    description?: pulumi.Input<string>;
    /**
     * Whether this dashboard is read-only. **Deprecated.** Prefer using `restrictedRoles` to define which roles are required to edit the dashboard.
     *
     * @deprecated Prefer using `restricted_roles` to define which roles are required to edit the dashboard.
     */
    isReadOnly?: pulumi.Input<boolean>;
    /**
     * The layout type of the dashboard. Valid values are `ordered`, `free`.
     */
    layoutType: pulumi.Input<string>;
    /**
     * The list of handles for the users to notify when changes are made to this dashboard.
     */
    notifyLists?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The reflow type of a new dashboard layout. Set this only when layout type is `ordered`. If set to `fixed`, the dashboard expects all widgets to have a layout, and if it's set to `auto`, widgets should not have layouts. Valid values are `auto`, `fixed`.
     */
    reflowType?: pulumi.Input<string>;
    /**
     * UUIDs of roles whose associated users are authorized to edit the dashboard.
     */
    restrictedRoles?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The list of selectable template variable presets for this dashboard.
     */
    templateVariablePresets?: pulumi.Input<pulumi.Input<inputs.DashboardTemplateVariablePreset>[]>;
    /**
     * The list of template variables for this dashboard.
     */
    templateVariables?: pulumi.Input<pulumi.Input<inputs.DashboardTemplateVariable>[]>;
    /**
     * The title of the dashboard.
     */
    title: pulumi.Input<string>;
    /**
     * The URL of the dashboard.
     */
    url?: pulumi.Input<string>;
    /**
     * The list of widgets to display on the dashboard.
     */
    widgets?: pulumi.Input<pulumi.Input<inputs.DashboardWidget>[]>;
}
