import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Datadog - Google Cloud Platform integration resource. This can be used to create and manage Datadog - Google Cloud Platform integration.
 *
 * ## Import
 *
 * Google Cloud Platform integrations can be imported using their project ID, e.g.
 *
 * ```sh
 *  $ pulumi import datadog:gcp/integration:Integration awesome_gcp_project_integration project_id
 * ```
 */
export declare class Integration extends pulumi.CustomResource {
    /**
     * Get an existing Integration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: IntegrationState, opts?: pulumi.CustomResourceOptions): Integration;
    /**
     * Returns true if the given object is an instance of Integration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Integration;
    /**
     * Silence monitors for expected GCE instance shutdowns.
     */
    readonly automute: pulumi.Output<boolean | undefined>;
    /**
     * Your email found in your JSON service account key.
     */
    readonly clientEmail: pulumi.Output<string>;
    /**
     * Your ID found in your JSON service account key.
     */
    readonly clientId: pulumi.Output<string>;
    /**
     * Whether Datadog collects cloud security posture management resources from your GCP project.
     */
    readonly cspmResourceCollectionEnabled: pulumi.Output<boolean | undefined>;
    /**
     * Limit the GCE instances that are pulled into Datadog by using tags. Only hosts that match one of the defined tags are imported into Datadog.
     */
    readonly hostFilters: pulumi.Output<string | undefined>;
    /**
     * Your private key name found in your JSON service account key.
     */
    readonly privateKey: pulumi.Output<string>;
    /**
     * Your private key ID found in your JSON service account key.
     */
    readonly privateKeyId: pulumi.Output<string>;
    /**
     * Your Google Cloud project ID found in your JSON service account key.
     */
    readonly projectId: pulumi.Output<string>;
    /**
     * Create a Integration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IntegrationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Integration resources.
 */
export interface IntegrationState {
    /**
     * Silence monitors for expected GCE instance shutdowns.
     */
    automute?: pulumi.Input<boolean>;
    /**
     * Your email found in your JSON service account key.
     */
    clientEmail?: pulumi.Input<string>;
    /**
     * Your ID found in your JSON service account key.
     */
    clientId?: pulumi.Input<string>;
    /**
     * Whether Datadog collects cloud security posture management resources from your GCP project.
     */
    cspmResourceCollectionEnabled?: pulumi.Input<boolean>;
    /**
     * Limit the GCE instances that are pulled into Datadog by using tags. Only hosts that match one of the defined tags are imported into Datadog.
     */
    hostFilters?: pulumi.Input<string>;
    /**
     * Your private key name found in your JSON service account key.
     */
    privateKey?: pulumi.Input<string>;
    /**
     * Your private key ID found in your JSON service account key.
     */
    privateKeyId?: pulumi.Input<string>;
    /**
     * Your Google Cloud project ID found in your JSON service account key.
     */
    projectId?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a Integration resource.
 */
export interface IntegrationArgs {
    /**
     * Silence monitors for expected GCE instance shutdowns.
     */
    automute?: pulumi.Input<boolean>;
    /**
     * Your email found in your JSON service account key.
     */
    clientEmail: pulumi.Input<string>;
    /**
     * Your ID found in your JSON service account key.
     */
    clientId: pulumi.Input<string>;
    /**
     * Whether Datadog collects cloud security posture management resources from your GCP project.
     */
    cspmResourceCollectionEnabled?: pulumi.Input<boolean>;
    /**
     * Limit the GCE instances that are pulled into Datadog by using tags. Only hosts that match one of the defined tags are imported into Datadog.
     */
    hostFilters?: pulumi.Input<string>;
    /**
     * Your private key name found in your JSON service account key.
     */
    privateKey: pulumi.Input<string>;
    /**
     * Your private key ID found in your JSON service account key.
     */
    privateKeyId: pulumi.Input<string>;
    /**
     * Your Google Cloud project ID found in your JSON service account key.
     */
    projectId: pulumi.Input<string>;
}
