import * as pulumi from "@pulumi/pulumi";
/**
 * Use this data source to retrieve information about an existing api key.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const foo = datadog.getApiKey({
 *     name: "foo-application",
 * });
 * ```
 */
export declare function getApiKey(args?: GetApiKeyArgs, opts?: pulumi.InvokeOptions): Promise<GetApiKeyResult>;
/**
 * A collection of arguments for invoking getApiKey.
 */
export interface GetApiKeyArgs {
    /**
     * Id for API Key.
     */
    id?: string;
    /**
     * Name for API Key.
     */
    name?: string;
}
/**
 * A collection of values returned by getApiKey.
 */
export interface GetApiKeyResult {
    /**
     * Id for API Key.
     */
    readonly id?: string;
    /**
     * The value of the API Key.
     */
    readonly key: string;
    /**
     * Name for API Key.
     */
    readonly name?: string;
}
/**
 * Use this data source to retrieve information about an existing api key.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const foo = datadog.getApiKey({
 *     name: "foo-application",
 * });
 * ```
 */
export declare function getApiKeyOutput(args?: GetApiKeyOutputArgs, opts?: pulumi.InvokeOptions): pulumi.Output<GetApiKeyResult>;
/**
 * A collection of arguments for invoking getApiKey.
 */
export interface GetApiKeyOutputArgs {
    /**
     * Id for API Key.
     */
    id?: pulumi.Input<string>;
    /**
     * Name for API Key.
     */
    name?: pulumi.Input<string>;
}
