import * as pulumi from "@pulumi/pulumi";
/**
 * Use this data source to retrieve information about an existing application key.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const foo = datadog.getApplicationKey({
 *     name: "foo-application",
 * });
 * ```
 */
export declare function getApplicationKey(args?: GetApplicationKeyArgs, opts?: pulumi.InvokeOptions): Promise<GetApplicationKeyResult>;
/**
 * A collection of arguments for invoking getApplicationKey.
 */
export interface GetApplicationKeyArgs {
    /**
     * Id for Application Key.
     */
    id?: string;
    /**
     * Name for Application Key.
     */
    name?: string;
}
/**
 * A collection of values returned by getApplicationKey.
 */
export interface GetApplicationKeyResult {
    /**
     * Id for Application Key.
     */
    readonly id?: string;
    /**
     * The value of the Application Key.
     */
    readonly key: string;
    /**
     * Name for Application Key.
     */
    readonly name?: string;
}
/**
 * Use this data source to retrieve information about an existing application key.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const foo = datadog.getApplicationKey({
 *     name: "foo-application",
 * });
 * ```
 */
export declare function getApplicationKeyOutput(args?: GetApplicationKeyOutputArgs, opts?: pulumi.InvokeOptions): pulumi.Output<GetApplicationKeyResult>;
/**
 * A collection of arguments for invoking getApplicationKey.
 */
export interface GetApplicationKeyOutputArgs {
    /**
     * Id for Application Key.
     */
    id?: pulumi.Input<string>;
    /**
     * Name for Application Key.
     */
    name?: pulumi.Input<string>;
}
