import * as pulumi from "@pulumi/pulumi";
/**
 * Use this data source to retrieve information about an existing dashboard, for use in other resources. In particular, it can be used in a monitor message to link to a specific dashboard.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const test = datadog.getDashboard({
 *     name: "My super dashboard",
 * });
 * ```
 */
export declare function getDashboard(args: GetDashboardArgs, opts?: pulumi.InvokeOptions): Promise<GetDashboardResult>;
/**
 * A collection of arguments for invoking getDashboard.
 */
export interface GetDashboardArgs {
    /**
     * The dashboard name to search for. Must only match one dashboard.
     */
    name: string;
}
/**
 * A collection of values returned by getDashboard.
 */
export interface GetDashboardResult {
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * The dashboard name to search for. Must only match one dashboard.
     */
    readonly name: string;
    /**
     * The name of the dashboard.
     */
    readonly title: string;
    /**
     * The URL to a specific dashboard.
     */
    readonly url: string;
}
/**
 * Use this data source to retrieve information about an existing dashboard, for use in other resources. In particular, it can be used in a monitor message to link to a specific dashboard.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const test = datadog.getDashboard({
 *     name: "My super dashboard",
 * });
 * ```
 */
export declare function getDashboardOutput(args: GetDashboardOutputArgs, opts?: pulumi.InvokeOptions): pulumi.Output<GetDashboardResult>;
/**
 * A collection of arguments for invoking getDashboard.
 */
export interface GetDashboardOutputArgs {
    /**
     * The dashboard name to search for. Must only match one dashboard.
     */
    name: pulumi.Input<string>;
}
