import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Use this data source to list several existing monitors for use in other resources.
 */
export declare function getMonitors(args?: GetMonitorsArgs, opts?: pulumi.InvokeOptions): Promise<GetMonitorsResult>;
/**
 * A collection of arguments for invoking getMonitors.
 */
export interface GetMonitorsArgs {
    /**
     * A list of monitor tags to limit the search. This filters on the tags set on the monitor itself.
     */
    monitorTagsFilters?: string[];
    /**
     * A monitor name to limit the search.
     */
    nameFilter?: string;
    /**
     * A list of tags to limit the search. This filters on the monitor scope.
     */
    tagsFilters?: string[];
}
/**
 * A collection of values returned by getMonitors.
 */
export interface GetMonitorsResult {
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * A list of monitor tags to limit the search. This filters on the tags set on the monitor itself.
     */
    readonly monitorTagsFilters?: string[];
    /**
     * List of monitors
     */
    readonly monitors: outputs.GetMonitorsMonitor[];
    /**
     * A monitor name to limit the search.
     */
    readonly nameFilter?: string;
    /**
     * A list of tags to limit the search. This filters on the monitor scope.
     */
    readonly tagsFilters?: string[];
}
/**
 * Use this data source to list several existing monitors for use in other resources.
 */
export declare function getMonitorsOutput(args?: GetMonitorsOutputArgs, opts?: pulumi.InvokeOptions): pulumi.Output<GetMonitorsResult>;
/**
 * A collection of arguments for invoking getMonitors.
 */
export interface GetMonitorsOutputArgs {
    /**
     * A list of monitor tags to limit the search. This filters on the tags set on the monitor itself.
     */
    monitorTagsFilters?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A monitor name to limit the search.
     */
    nameFilter?: pulumi.Input<string>;
    /**
     * A list of tags to limit the search. This filters on the monitor scope.
     */
    tagsFilters?: pulumi.Input<pulumi.Input<string>[]>;
}
