import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Use this data source to retrieve information about multiple roles for use in other resources.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const foo = datadog.getRoles({
 *     filter: "Datadog",
 * });
 * ```
 */
export declare function getRoles(args?: GetRolesArgs, opts?: pulumi.InvokeOptions): Promise<GetRolesResult>;
/**
 * A collection of arguments for invoking getRoles.
 */
export interface GetRolesArgs {
    /**
     * Filter all roles by the given string.
     */
    filter?: string;
}
/**
 * A collection of values returned by getRoles.
 */
export interface GetRolesResult {
    /**
     * Filter all roles by the given string.
     */
    readonly filter?: string;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * List of Roles
     */
    readonly roles: outputs.GetRolesRole[];
}
/**
 * Use this data source to retrieve information about multiple roles for use in other resources.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const foo = datadog.getRoles({
 *     filter: "Datadog",
 * });
 * ```
 */
export declare function getRolesOutput(args?: GetRolesOutputArgs, opts?: pulumi.InvokeOptions): pulumi.Output<GetRolesResult>;
/**
 * A collection of arguments for invoking getRoles.
 */
export interface GetRolesOutputArgs {
    /**
     * Filter all roles by the given string.
     */
    filter?: pulumi.Input<string>;
}
