import * as pulumi from "@pulumi/pulumi";
/**
 * Use this data source to retrieve a Datadog RUM Application.
 */
export declare function getRumApplication(args?: GetRumApplicationArgs, opts?: pulumi.InvokeOptions): Promise<GetRumApplicationResult>;
/**
 * A collection of arguments for invoking getRumApplication.
 */
export interface GetRumApplicationArgs {
    /**
     * ID of the RUM application. Cannot be used with name and type filters.
     */
    id?: string;
    /**
     * The name used to search for a RUM application
     */
    nameFilter?: string;
    /**
     * The type used to search for a RUM application
     */
    typeFilter?: string;
}
/**
 * A collection of values returned by getRumApplication.
 */
export interface GetRumApplicationResult {
    /**
     * The client token
     */
    readonly clientToken: string;
    /**
     * ID of the RUM application. Cannot be used with name and type filters.
     */
    readonly id: string;
    /**
     * The name of the RUM application
     */
    readonly name: string;
    /**
     * The name used to search for a RUM application
     */
    readonly nameFilter?: string;
    /**
     * The RUM application type. Supported values are `browser`, `ios`, `android`, `react-native`, `flutter`
     */
    readonly type: string;
    /**
     * The type used to search for a RUM application
     */
    readonly typeFilter?: string;
}
/**
 * Use this data source to retrieve a Datadog RUM Application.
 */
export declare function getRumApplicationOutput(args?: GetRumApplicationOutputArgs, opts?: pulumi.InvokeOptions): pulumi.Output<GetRumApplicationResult>;
/**
 * A collection of arguments for invoking getRumApplication.
 */
export interface GetRumApplicationOutputArgs {
    /**
     * ID of the RUM application. Cannot be used with name and type filters.
     */
    id?: pulumi.Input<string>;
    /**
     * The name used to search for a RUM application
     */
    nameFilter?: pulumi.Input<string>;
    /**
     * The type used to search for a RUM application
     */
    typeFilter?: pulumi.Input<string>;
}
