import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Use this data source to retrieve information about existing security monitoring rules for use in other resources.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const test = datadog.getSecurityMonitoringRules({
 *     defaultOnlyFilter: true,
 *     nameFilter: "attack",
 *     tagsFilters: ["foo:bar"],
 * });
 * ```
 */
export declare function getSecurityMonitoringRules(args?: GetSecurityMonitoringRulesArgs, opts?: pulumi.InvokeOptions): Promise<GetSecurityMonitoringRulesResult>;
/**
 * A collection of arguments for invoking getSecurityMonitoringRules.
 */
export interface GetSecurityMonitoringRulesArgs {
    /**
     * Limit the search to default rules
     */
    defaultOnlyFilter?: boolean;
    /**
     * A rule name to limit the search
     */
    nameFilter?: string;
    /**
     * A list of tags to limit the search
     */
    tagsFilters?: string[];
    /**
     * Limit the search to user rules
     */
    userOnlyFilter?: boolean;
}
/**
 * A collection of values returned by getSecurityMonitoringRules.
 */
export interface GetSecurityMonitoringRulesResult {
    /**
     * Limit the search to default rules
     */
    readonly defaultOnlyFilter?: boolean;
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    /**
     * A rule name to limit the search
     */
    readonly nameFilter?: string;
    /**
     * List of IDs of the matched rules.
     */
    readonly ruleIds: string[];
    /**
     * List of rules.
     */
    readonly rules: outputs.GetSecurityMonitoringRulesRule[];
    /**
     * A list of tags to limit the search
     */
    readonly tagsFilters?: string[];
    /**
     * Limit the search to user rules
     */
    readonly userOnlyFilter?: boolean;
}
/**
 * Use this data source to retrieve information about existing security monitoring rules for use in other resources.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const test = datadog.getSecurityMonitoringRules({
 *     defaultOnlyFilter: true,
 *     nameFilter: "attack",
 *     tagsFilters: ["foo:bar"],
 * });
 * ```
 */
export declare function getSecurityMonitoringRulesOutput(args?: GetSecurityMonitoringRulesOutputArgs, opts?: pulumi.InvokeOptions): pulumi.Output<GetSecurityMonitoringRulesResult>;
/**
 * A collection of arguments for invoking getSecurityMonitoringRules.
 */
export interface GetSecurityMonitoringRulesOutputArgs {
    /**
     * Limit the search to default rules
     */
    defaultOnlyFilter?: pulumi.Input<boolean>;
    /**
     * A rule name to limit the search
     */
    nameFilter?: pulumi.Input<string>;
    /**
     * A list of tags to limit the search
     */
    tagsFilters?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Limit the search to user rules
     */
    userOnlyFilter?: pulumi.Input<boolean>;
}
