import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Provides the Datadog IP allowlist resource. This can be used to manage the Datadog IP allowlist
 */
export declare class IpAllowlist extends pulumi.CustomResource {
    /**
     * Get an existing IpAllowlist resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: IpAllowlistState, opts?: pulumi.CustomResourceOptions): IpAllowlist;
    /**
     * Returns true if the given object is an instance of IpAllowlist.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is IpAllowlist;
    /**
     * Whether the IP Allowlist is enabled.
     */
    readonly enabled: pulumi.Output<boolean>;
    /**
     * Set of objects containing an IP address or range of IP addresses in the allowlist and an accompanying note.
     */
    readonly entries: pulumi.Output<outputs.IpAllowlistEntry[] | undefined>;
    /**
     * Create a IpAllowlist resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IpAllowlistArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering IpAllowlist resources.
 */
export interface IpAllowlistState {
    /**
     * Whether the IP Allowlist is enabled.
     */
    enabled?: pulumi.Input<boolean>;
    /**
     * Set of objects containing an IP address or range of IP addresses in the allowlist and an accompanying note.
     */
    entries?: pulumi.Input<pulumi.Input<inputs.IpAllowlistEntry>[]>;
}
/**
 * The set of arguments for constructing a IpAllowlist resource.
 */
export interface IpAllowlistArgs {
    /**
     * Whether the IP Allowlist is enabled.
     */
    enabled: pulumi.Input<boolean>;
    /**
     * Set of objects containing an IP address or range of IP addresses in the allowlist and an accompanying note.
     */
    entries?: pulumi.Input<pulumi.Input<inputs.IpAllowlistEntry>[]>;
}
