import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Provides a Datadog [Logs Pipeline API](https://docs.datadoghq.com/api/v1/logs-pipelines/) resource, which is used to create and manage Datadog logs custom pipelines. Each `datadog.LogsCustomPipeline` resource defines a complete pipeline. The order of the pipelines is maintained in a different resource: `datadog.LogsPipelineOrder`. When creating a new pipeline, you need to **explicitly** add this pipeline to the `datadog.LogsPipelineOrder` resource to track the pipeline. Similarly, when a pipeline needs to be destroyed, remove its references from the `datadog.LogsPipelineOrder` resource.
 *
 * ## Import
 *
 * To find the pipeline ID, click the "edit" button in the UI to open the pipeline details. The pipeline ID is the last part of the URL.
 *
 * ```sh
 *  $ pulumi import datadog:index/logsCustomPipeline:LogsCustomPipeline name> <pipelineID>
 * ```
 */
export declare class LogsCustomPipeline extends pulumi.CustomResource {
    /**
     * Get an existing LogsCustomPipeline resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: LogsCustomPipelineState, opts?: pulumi.CustomResourceOptions): LogsCustomPipeline;
    /**
     * Returns true if the given object is an instance of LogsCustomPipeline.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LogsCustomPipeline;
    readonly filters: pulumi.Output<outputs.LogsCustomPipelineFilter[]>;
    readonly isEnabled: pulumi.Output<boolean | undefined>;
    readonly name: pulumi.Output<string>;
    readonly processors: pulumi.Output<outputs.LogsCustomPipelineProcessor[] | undefined>;
    /**
     * Create a LogsCustomPipeline resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LogsCustomPipelineArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering LogsCustomPipeline resources.
 */
export interface LogsCustomPipelineState {
    filters?: pulumi.Input<pulumi.Input<inputs.LogsCustomPipelineFilter>[]>;
    isEnabled?: pulumi.Input<boolean>;
    name?: pulumi.Input<string>;
    processors?: pulumi.Input<pulumi.Input<inputs.LogsCustomPipelineProcessor>[]>;
}
/**
 * The set of arguments for constructing a LogsCustomPipeline resource.
 */
export interface LogsCustomPipelineArgs {
    filters: pulumi.Input<pulumi.Input<inputs.LogsCustomPipelineFilter>[]>;
    isEnabled?: pulumi.Input<boolean>;
    name: pulumi.Input<string>;
    processors?: pulumi.Input<pulumi.Input<inputs.LogsCustomPipelineProcessor>[]>;
}
