import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Datadog Logs Index API resource. This can be used to manage the order of Datadog logs indexes.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const sampleIndexOrder = new datadog.LogsIndexOrder("sampleIndexOrder", {
 *     name: "sample_index_order",
 *     indexes: [datadog_logs_index.sample_index.id],
 * });
 * ```
 *
 * ## Import
 *
 * The Datadog Terraform Provider does not support the creation and deletion of index orders. There must be at most one `datadog_logs_index_order` resource `<name>` can be whatever you specify in your code. Datadog does not store the name on the server.
 *
 * ```sh
 *  $ pulumi import datadog:index/logsIndexOrder:LogsIndexOrder name> <name>
 * ```
 */
export declare class LogsIndexOrder extends pulumi.CustomResource {
    /**
     * Get an existing LogsIndexOrder resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: LogsIndexOrderState, opts?: pulumi.CustomResourceOptions): LogsIndexOrder;
    /**
     * Returns true if the given object is an instance of LogsIndexOrder.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LogsIndexOrder;
    /**
     * The index resource list. Logs are tested against the query filter of each index one by one following the order of the list.
     */
    readonly indexes: pulumi.Output<string[]>;
    /**
     * The unique name of the index order resource.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Create a LogsIndexOrder resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LogsIndexOrderArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering LogsIndexOrder resources.
 */
export interface LogsIndexOrderState {
    /**
     * The index resource list. Logs are tested against the query filter of each index one by one following the order of the list.
     */
    indexes?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The unique name of the index order resource.
     */
    name?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a LogsIndexOrder resource.
 */
export interface LogsIndexOrderArgs {
    /**
     * The index resource list. Logs are tested against the query filter of each index one by one following the order of the list.
     */
    indexes: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The unique name of the index order resource.
     */
    name?: pulumi.Input<string>;
}
