import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Resource for interacting with the logsMetric API
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const testingLogsMetric = new datadog.LogsMetric("testingLogsMetric", {
 *     compute: {
 *         aggregationType: "distribution",
 *         path: "@duration",
 *     },
 *     filter: {
 *         query: "service:test",
 *     },
 *     groupBies: [
 *         {
 *             path: "@status",
 *             tagName: "status",
 *         },
 *         {
 *             path: "@version",
 *             tagName: "version",
 *         },
 *     ],
 *     name: "testing.logs.metric",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 *  $ pulumi import datadog:index/logsMetric:LogsMetric testing_logs_metric testing.logs.metric
 * ```
 */
export declare class LogsMetric extends pulumi.CustomResource {
    /**
     * Get an existing LogsMetric resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: LogsMetricState, opts?: pulumi.CustomResourceOptions): LogsMetric;
    /**
     * Returns true if the given object is an instance of LogsMetric.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LogsMetric;
    /**
     * The compute rule to compute the log-based metric. This field can't be updated after creation.
     */
    readonly compute: pulumi.Output<outputs.LogsMetricCompute>;
    /**
     * The log-based metric filter. Logs matching this filter will be aggregated in this metric.
     */
    readonly filter: pulumi.Output<outputs.LogsMetricFilter>;
    /**
     * The rules for the group by.
     */
    readonly groupBies: pulumi.Output<outputs.LogsMetricGroupBy[] | undefined>;
    /**
     * The name of the log-based metric. This field can't be updated after creation.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Create a LogsMetric resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LogsMetricArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering LogsMetric resources.
 */
export interface LogsMetricState {
    /**
     * The compute rule to compute the log-based metric. This field can't be updated after creation.
     */
    compute?: pulumi.Input<inputs.LogsMetricCompute>;
    /**
     * The log-based metric filter. Logs matching this filter will be aggregated in this metric.
     */
    filter?: pulumi.Input<inputs.LogsMetricFilter>;
    /**
     * The rules for the group by.
     */
    groupBies?: pulumi.Input<pulumi.Input<inputs.LogsMetricGroupBy>[]>;
    /**
     * The name of the log-based metric. This field can't be updated after creation.
     */
    name?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a LogsMetric resource.
 */
export interface LogsMetricArgs {
    /**
     * The compute rule to compute the log-based metric. This field can't be updated after creation.
     */
    compute: pulumi.Input<inputs.LogsMetricCompute>;
    /**
     * The log-based metric filter. Logs matching this filter will be aggregated in this metric.
     */
    filter: pulumi.Input<inputs.LogsMetricFilter>;
    /**
     * The rules for the group by.
     */
    groupBies?: pulumi.Input<pulumi.Input<inputs.LogsMetricGroupBy>[]>;
    /**
     * The name of the log-based metric. This field can't be updated after creation.
     */
    name: pulumi.Input<string>;
}
