import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Datadog Logs Pipeline API resource, which is used to manage Datadog log pipelines order.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const samplePipelineOrder = new datadog.LogsPipelineOrder("samplePipelineOrder", {
 *     name: "sample_pipeline_order",
 *     pipelines: [
 *         datadog_logs_custom_pipeline.sample_pipeline.id,
 *         datadog_logs_integration_pipeline.python.id,
 *     ],
 * });
 * ```
 *
 * ## Import
 *
 * There must be at most one datadog_logs_pipeline_order resource. Pipeline order creation is not supported from logs config API. You can import the datadog_logs_pipeline_order or create a pipeline order (which is actually doing the update operation).
 *
 * ```sh
 *  $ pulumi import datadog:index/logsPipelineOrder:LogsPipelineOrder name> <name>
 * ```
 */
export declare class LogsPipelineOrder extends pulumi.CustomResource {
    /**
     * Get an existing LogsPipelineOrder resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: LogsPipelineOrderState, opts?: pulumi.CustomResourceOptions): LogsPipelineOrder;
    /**
     * Returns true if the given object is an instance of LogsPipelineOrder.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LogsPipelineOrder;
    /**
     * The name attribute in the resource `datadog.LogsPipelineOrder` needs to be unique. It's recommended to use the same value as the resource name. No related field is available in [Logs Pipeline API](https://docs.datadoghq.com/api/v1/logs-pipelines/#get-pipeline-order).
     */
    readonly name: pulumi.Output<string>;
    /**
     * The pipeline IDs list. The order of pipeline IDs in this attribute defines the overall pipeline order for logs.
     */
    readonly pipelines: pulumi.Output<string[]>;
    /**
     * Create a LogsPipelineOrder resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LogsPipelineOrderArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering LogsPipelineOrder resources.
 */
export interface LogsPipelineOrderState {
    /**
     * The name attribute in the resource `datadog.LogsPipelineOrder` needs to be unique. It's recommended to use the same value as the resource name. No related field is available in [Logs Pipeline API](https://docs.datadoghq.com/api/v1/logs-pipelines/#get-pipeline-order).
     */
    name?: pulumi.Input<string>;
    /**
     * The pipeline IDs list. The order of pipeline IDs in this attribute defines the overall pipeline order for logs.
     */
    pipelines?: pulumi.Input<pulumi.Input<string>[]>;
}
/**
 * The set of arguments for constructing a LogsPipelineOrder resource.
 */
export interface LogsPipelineOrderArgs {
    /**
     * The name attribute in the resource `datadog.LogsPipelineOrder` needs to be unique. It's recommended to use the same value as the resource name. No related field is available in [Logs Pipeline API](https://docs.datadoghq.com/api/v1/logs-pipelines/#get-pipeline-order).
     */
    name: pulumi.Input<string>;
    /**
     * The pipeline IDs list. The order of pipeline IDs in this attribute defines the overall pipeline order for logs.
     */
    pipelines: pulumi.Input<pulumi.Input<string>[]>;
}
