import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Datadog metricMetadata resource. This can be used to manage a metric's metadata.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * // Manage a Datadog metric's metadata
 * const requestTime = new datadog.MetricMetadata("requestTime", {
 *     description: "99th percentile request time in millseconds",
 *     metric: "request.time",
 *     shortName: "Request time",
 *     type: "gauge",
 *     unit: "millisecond",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 *  $ pulumi import datadog:index/metricMetadata:MetricMetadata request_time request.time
 * ```
 */
export declare class MetricMetadata extends pulumi.CustomResource {
    /**
     * Get an existing MetricMetadata resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: MetricMetadataState, opts?: pulumi.CustomResourceOptions): MetricMetadata;
    /**
     * Returns true if the given object is an instance of MetricMetadata.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is MetricMetadata;
    /**
     * A description of the metric.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The name of the metric.
     */
    readonly metric: pulumi.Output<string>;
    /**
     * Per unit of the metric such as `second` in `bytes per second`.
     */
    readonly perUnit: pulumi.Output<string | undefined>;
    /**
     * A short name of the metric.
     */
    readonly shortName: pulumi.Output<string | undefined>;
    /**
     * If applicable, statsd flush interval in seconds for the metric.
     */
    readonly statsdInterval: pulumi.Output<number | undefined>;
    /**
     * Metric type such as `gauge` or `rate`.
     */
    readonly type: pulumi.Output<string | undefined>;
    /**
     * Primary unit of the metric such as `byte` or `operation`.
     */
    readonly unit: pulumi.Output<string | undefined>;
    /**
     * Create a MetricMetadata resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: MetricMetadataArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering MetricMetadata resources.
 */
export interface MetricMetadataState {
    /**
     * A description of the metric.
     */
    description?: pulumi.Input<string>;
    /**
     * The name of the metric.
     */
    metric?: pulumi.Input<string>;
    /**
     * Per unit of the metric such as `second` in `bytes per second`.
     */
    perUnit?: pulumi.Input<string>;
    /**
     * A short name of the metric.
     */
    shortName?: pulumi.Input<string>;
    /**
     * If applicable, statsd flush interval in seconds for the metric.
     */
    statsdInterval?: pulumi.Input<number>;
    /**
     * Metric type such as `gauge` or `rate`.
     */
    type?: pulumi.Input<string>;
    /**
     * Primary unit of the metric such as `byte` or `operation`.
     */
    unit?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a MetricMetadata resource.
 */
export interface MetricMetadataArgs {
    /**
     * A description of the metric.
     */
    description?: pulumi.Input<string>;
    /**
     * The name of the metric.
     */
    metric: pulumi.Input<string>;
    /**
     * Per unit of the metric such as `second` in `bytes per second`.
     */
    perUnit?: pulumi.Input<string>;
    /**
     * A short name of the metric.
     */
    shortName?: pulumi.Input<string>;
    /**
     * If applicable, statsd flush interval in seconds for the metric.
     */
    statsdInterval?: pulumi.Input<number>;
    /**
     * Metric type such as `gauge` or `rate`.
     */
    type?: pulumi.Input<string>;
    /**
     * Primary unit of the metric such as `byte` or `operation`.
     */
    unit?: pulumi.Input<string>;
}
