import * as pulumi from "@pulumi/pulumi";
/**
 * Resource for interacting with Datadog Opsgenie Service API.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const fakeServiceName = new datadog.opsgenie.ServiceObject("fakeServiceName", {
 *     name: "fake_service_name",
 *     opsgenieApiKey: "00000000-0000-0000-0000-000000000000",
 *     region: "us",
 * });
 * const fakeServiceName2 = new datadog.opsgenie.ServiceObject("fakeServiceName2", {
 *     name: "fake_service_name_2",
 *     opsgenieApiKey: "11111111-1111-1111-1111-111111111111",
 *     region: "eu",
 * });
 * ```
 */
export declare class ServiceObject extends pulumi.CustomResource {
    /**
     * Get an existing ServiceObject resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ServiceObjectState, opts?: pulumi.CustomResourceOptions): ServiceObject;
    /**
     * Returns true if the given object is an instance of ServiceObject.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ServiceObject;
    /**
     * The custom url for a custom region.
     */
    readonly customUrl: pulumi.Output<string | undefined>;
    /**
     * The name for the Opsgenie service.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The Opsgenie API key for the Opsgenie service. Note: Since the Datadog API never returns Opsgenie API keys, it is
     * impossible to detect [drifts](https://www.hashicorp.com/blog/detecting-and-managing-drift-with-terraform). The best way
     * to solve a drift is to manually mark the Service Object resource with [terraform
     * taint](https://www.terraform.io/docs/commands/taint.html) to have it destroyed and recreated.
     */
    readonly opsgenieApiKey: pulumi.Output<string>;
    /**
     * The region for the Opsgenie service. Valid values are `us`, `eu`, `custom`.
     */
    readonly region: pulumi.Output<string>;
    /**
     * Create a ServiceObject resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ServiceObjectArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ServiceObject resources.
 */
export interface ServiceObjectState {
    /**
     * The custom url for a custom region.
     */
    customUrl?: pulumi.Input<string>;
    /**
     * The name for the Opsgenie service.
     */
    name?: pulumi.Input<string>;
    /**
     * The Opsgenie API key for the Opsgenie service. Note: Since the Datadog API never returns Opsgenie API keys, it is
     * impossible to detect [drifts](https://www.hashicorp.com/blog/detecting-and-managing-drift-with-terraform). The best way
     * to solve a drift is to manually mark the Service Object resource with [terraform
     * taint](https://www.terraform.io/docs/commands/taint.html) to have it destroyed and recreated.
     */
    opsgenieApiKey?: pulumi.Input<string>;
    /**
     * The region for the Opsgenie service. Valid values are `us`, `eu`, `custom`.
     */
    region?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ServiceObject resource.
 */
export interface ServiceObjectArgs {
    /**
     * The custom url for a custom region.
     */
    customUrl?: pulumi.Input<string>;
    /**
     * The name for the Opsgenie service.
     */
    name: pulumi.Input<string>;
    /**
     * The Opsgenie API key for the Opsgenie service. Note: Since the Datadog API never returns Opsgenie API keys, it is
     * impossible to detect [drifts](https://www.hashicorp.com/blog/detecting-and-managing-drift-with-terraform). The best way
     * to solve a drift is to manually mark the Service Object resource with [terraform
     * taint](https://www.terraform.io/docs/commands/taint.html) to have it destroyed and recreated.
     */
    opsgenieApiKey: pulumi.Input<string>;
    /**
     * The region for the Opsgenie service. Valid values are `us`, `eu`, `custom`.
     */
    region: pulumi.Input<string>;
}
