import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Provides a Datadog Organization resource. This can be used to manage your Datadog organization's settings.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * // Manage Datadog Organization
 * const organization = new datadog.OrganizationSettings("organization", {name: "foo-organization"});
 * ```
 *
 * ## Import
 *
 * ```sh
 *  $ pulumi import datadog:index/organizationSettings:OrganizationSettings organization 11111111-2222-3333-4444-555555555555
 * ```
 */
export declare class OrganizationSettings extends pulumi.CustomResource {
    /**
     * Get an existing OrganizationSettings resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: OrganizationSettingsState, opts?: pulumi.CustomResourceOptions): OrganizationSettings;
    /**
     * Returns true if the given object is an instance of OrganizationSettings.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is OrganizationSettings;
    /**
     * Description of the organization.
     */
    readonly description: pulumi.Output<string>;
    /**
     * Name for Organization.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * The `publicId` of the organization you are operating within.
     */
    readonly publicId: pulumi.Output<string>;
    /**
     * Organization settings
     */
    readonly settings: pulumi.Output<outputs.OrganizationSettingsSettings>;
    /**
     * Create a OrganizationSettings resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: OrganizationSettingsArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering OrganizationSettings resources.
 */
export interface OrganizationSettingsState {
    /**
     * Description of the organization.
     */
    description?: pulumi.Input<string>;
    /**
     * Name for Organization.
     */
    name?: pulumi.Input<string>;
    /**
     * The `publicId` of the organization you are operating within.
     */
    publicId?: pulumi.Input<string>;
    /**
     * Organization settings
     */
    settings?: pulumi.Input<inputs.OrganizationSettingsSettings>;
}
/**
 * The set of arguments for constructing a OrganizationSettings resource.
 */
export interface OrganizationSettingsArgs {
    /**
     * Name for Organization.
     */
    name?: pulumi.Input<string>;
    /**
     * Organization settings
     */
    settings?: pulumi.Input<inputs.OrganizationSettingsSettings>;
}
