import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Datadog - PagerDuty resource. This can be used to create and manage Datadog - PagerDuty integration. See also [PagerDuty Integration Guide](https://www.pagerduty.com/docs/guides/datadog-integration-guide/).
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const pd = new datadog.pagerduty.Integration("pd", {
 *     apiToken: "38457822378273432587234242874",
 *     schedules: [
 *         "https://ddog.pagerduty.com/schedules/X123VF",
 *         "https://ddog.pagerduty.com/schedules/X321XX",
 *     ],
 *     subdomain: "ddog",
 * });
 * const testingFoo = new datadog.pagerduty.ServiceObject("testingFoo", {
 *     serviceKey: "9876543210123456789",
 *     serviceName: "testing_foo",
 * }, {
 *     dependsOn: ["datadog_integration_pagerduty.pd"],
 * });
 * const testingBar = new datadog.pagerduty.ServiceObject("testingBar", {
 *     serviceKey: "54321098765432109876",
 *     serviceName: "testing_bar",
 * }, {
 *     dependsOn: ["datadog_integration_pagerduty.pd"],
 * });
 * ```
 */
export declare class Integration extends pulumi.CustomResource {
    /**
     * Get an existing Integration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: IntegrationState, opts?: pulumi.CustomResourceOptions): Integration;
    /**
     * Returns true if the given object is an instance of Integration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Integration;
    /**
     * Your PagerDuty API token.
     */
    readonly apiToken: pulumi.Output<string | undefined>;
    /**
     * Array of your schedule URLs.
     */
    readonly schedules: pulumi.Output<string[] | undefined>;
    /**
     * Your PagerDuty account’s personalized subdomain name.
     */
    readonly subdomain: pulumi.Output<string>;
    /**
     * Create a Integration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IntegrationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Integration resources.
 */
export interface IntegrationState {
    /**
     * Your PagerDuty API token.
     */
    apiToken?: pulumi.Input<string>;
    /**
     * Array of your schedule URLs.
     */
    schedules?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Your PagerDuty account’s personalized subdomain name.
     */
    subdomain?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a Integration resource.
 */
export interface IntegrationArgs {
    /**
     * Your PagerDuty API token.
     */
    apiToken?: pulumi.Input<string>;
    /**
     * Array of your schedule URLs.
     */
    schedules?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Your PagerDuty account’s personalized subdomain name.
     */
    subdomain: pulumi.Input<string>;
}
