import * as pulumi from "@pulumi/pulumi";
/**
 * Provides access to individual Service Objects of Datadog - PagerDuty integrations. Note that the Datadog - PagerDuty integration must be activated in the Datadog UI in order for this resource to be usable.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const testingFoo = new datadog.pagerduty.ServiceObject("testingFoo", {
 *     serviceKey: "9876543210123456789",
 *     serviceName: "testing_foo",
 * });
 * const testingBar = new datadog.pagerduty.ServiceObject("testingBar", {
 *     serviceKey: "54321098765432109876",
 *     serviceName: "testing_bar",
 * });
 * ```
 */
export declare class ServiceObject extends pulumi.CustomResource {
    /**
     * Get an existing ServiceObject resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ServiceObjectState, opts?: pulumi.CustomResourceOptions): ServiceObject;
    /**
     * Returns true if the given object is an instance of ServiceObject.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ServiceObject;
    /**
     * Your Service name associated service key in PagerDuty. Note: Since the Datadog API never returns service keys, it is impossible to detect drifts.
     */
    readonly serviceKey: pulumi.Output<string>;
    /**
     * Your Service name in PagerDuty.
     */
    readonly serviceName: pulumi.Output<string>;
    /**
     * Create a ServiceObject resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ServiceObjectArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ServiceObject resources.
 */
export interface ServiceObjectState {
    /**
     * Your Service name associated service key in PagerDuty. Note: Since the Datadog API never returns service keys, it is impossible to detect drifts.
     */
    serviceKey?: pulumi.Input<string>;
    /**
     * Your Service name in PagerDuty.
     */
    serviceName?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ServiceObject resource.
 */
export interface ServiceObjectArgs {
    /**
     * Your Service name associated service key in PagerDuty. Note: Since the Datadog API never returns service keys, it is impossible to detect drifts.
     */
    serviceKey: pulumi.Input<string>;
    /**
     * Your Service name in PagerDuty.
     */
    serviceName: pulumi.Input<string>;
}
