import * as pulumi from "@pulumi/pulumi";
/**
 * The provider type for the datadog package. By default, resources use package-wide configuration
 * settings, however an explicit `Provider` instance may be created and passed during resource
 * construction to achieve fine-grained programmatic control over provider settings. See the
 * [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.
 */
export declare class Provider extends pulumi.ProviderResource {
    /**
     * Returns true if the given object is an instance of Provider.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Provider;
    /**
     * (Required unless validate is false) Datadog API key. This can also be set via the DD_API_KEY environment variable.
     */
    readonly apiKey: pulumi.Output<string | undefined>;
    /**
     * The API URL. This can also be set via the DD_HOST environment variable. Note that this URL must not end with the `/api/`
     * path. For example, `https://api.datadoghq.com/` is a correct value, while `https://api.datadoghq.com/api/` is not. And
     * if you're working with "EU" version of Datadog, use `https://api.datadoghq.eu/`. Other Datadog region examples:
     * `https://api.us5.datadoghq.com/`, `https://api.us3.datadoghq.com/` and `https://api.ddog-gov.com/`. See
     * https://docs.datadoghq.com/getting_started/site/ for all available regions.
     */
    readonly apiUrl: pulumi.Output<string | undefined>;
    /**
     * (Required unless validate is false) Datadog APP key. This can also be set via the DD_APP_KEY environment variable.
     */
    readonly appKey: pulumi.Output<string | undefined>;
    /**
     * Create a Provider resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ProviderArgs, opts?: pulumi.ResourceOptions);
}
/**
 * The set of arguments for constructing a Provider resource.
 */
export interface ProviderArgs {
    /**
     * (Required unless validate is false) Datadog API key. This can also be set via the DD_API_KEY environment variable.
     */
    apiKey?: pulumi.Input<string>;
    /**
     * The API URL. This can also be set via the DD_HOST environment variable. Note that this URL must not end with the `/api/`
     * path. For example, `https://api.datadoghq.com/` is a correct value, while `https://api.datadoghq.com/api/` is not. And
     * if you're working with "EU" version of Datadog, use `https://api.datadoghq.eu/`. Other Datadog region examples:
     * `https://api.us5.datadoghq.com/`, `https://api.us3.datadoghq.com/` and `https://api.ddog-gov.com/`. See
     * https://docs.datadoghq.com/getting_started/site/ for all available regions.
     */
    apiUrl?: pulumi.Input<string>;
    /**
     * (Required unless validate is false) Datadog APP key. This can also be set via the DD_APP_KEY environment variable.
     */
    appKey?: pulumi.Input<string>;
    /**
     * The HTTP request retry back off base. Defaults to 2.
     */
    httpClientRetryBackoffBase?: pulumi.Input<number>;
    /**
     * The HTTP request retry back off multiplier. Defaults to 2.
     */
    httpClientRetryBackoffMultiplier?: pulumi.Input<number>;
    /**
     * Enables request retries on HTTP status codes 429 and 5xx. Defaults to `true`.
     */
    httpClientRetryEnabled?: pulumi.Input<boolean>;
    /**
     * The HTTP request maximum retry number. Defaults to 3.
     */
    httpClientRetryMaxRetries?: pulumi.Input<number>;
    /**
     * The HTTP request retry timeout period. Defaults to 60 seconds.
     */
    httpClientRetryTimeout?: pulumi.Input<number>;
    /**
     * Enables validation of the provided API and APP keys during provider initialization. Default is true. When false, api_key
     * and app_key won't be checked.
     */
    validate?: pulumi.Input<boolean>;
}
