import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Datadog RUM application resource. This can be used to create and manage Datadog RUM applications.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const rumApplication = new datadog.RumApplication("rumApplication", {
 *     name: "my-application",
 *     type: "browser",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 *  $ pulumi import datadog:index/rumApplication:RumApplication rum_application a1b2c3d4-a1b2-a1b2-a1b2-a1b2c3d4e5f6
 * ```
 */
export declare class RumApplication extends pulumi.CustomResource {
    /**
     * Get an existing RumApplication resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: RumApplicationState, opts?: pulumi.CustomResourceOptions): RumApplication;
    /**
     * Returns true if the given object is an instance of RumApplication.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is RumApplication;
    /**
     * The client token
     */
    readonly clientToken: pulumi.Output<string>;
    /**
     * The name of the RUM application
     */
    readonly name: pulumi.Output<string>;
    /**
     * The RUM application type. Supported values are `browser`, `ios`, `android`, `react-native`, `flutter`
     */
    readonly type: pulumi.Output<string | undefined>;
    /**
     * Create a RumApplication resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RumApplicationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering RumApplication resources.
 */
export interface RumApplicationState {
    /**
     * The client token
     */
    clientToken?: pulumi.Input<string>;
    /**
     * The name of the RUM application
     */
    name?: pulumi.Input<string>;
    /**
     * The RUM application type. Supported values are `browser`, `ios`, `android`, `react-native`, `flutter`
     */
    type?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a RumApplication resource.
 */
export interface RumApplicationArgs {
    /**
     * The name of the RUM application
     */
    name: pulumi.Input<string>;
    /**
     * The RUM application type. Supported values are `browser`, `ios`, `android`, `react-native`, `flutter`
     */
    type?: pulumi.Input<string>;
}
