import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Provides a Datadog Security Monitoring Rule API resource for security filters.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const myFilter = new datadog.SecurityMonitoringFilter("myFilter", {
 *     exclusionFilters: [
 *         {
 *             name: "first",
 *             query: "exclude some logs",
 *         },
 *         {
 *             name: "second",
 *             query: "exclude some other logs",
 *         },
 *     ],
 *     isEnabled: true,
 *     name: "My filter",
 *     query: "The filter is filtering.",
 * });
 * ```
 *
 * ## Import
 *
 * Security monitoring filters can be imported using ID, e.g.
 *
 * ```sh
 *  $ pulumi import datadog:index/securityMonitoringFilter:SecurityMonitoringFilter my_filter m0o-hto-lkb
 * ```
 */
export declare class SecurityMonitoringFilter extends pulumi.CustomResource {
    /**
     * Get an existing SecurityMonitoringFilter resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: SecurityMonitoringFilterState, opts?: pulumi.CustomResourceOptions): SecurityMonitoringFilter;
    /**
     * Returns true if the given object is an instance of SecurityMonitoringFilter.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SecurityMonitoringFilter;
    /**
     * Exclusion filters to exclude some logs from the security filter.
     */
    readonly exclusionFilters: pulumi.Output<outputs.SecurityMonitoringFilterExclusionFilter[] | undefined>;
    /**
     * The filtered data type. Valid values are `logs`.
     */
    readonly filteredDataType: pulumi.Output<string | undefined>;
    /**
     * Whether the security filter is enabled.
     */
    readonly isEnabled: pulumi.Output<boolean>;
    /**
     * The name of the security filter.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The query of the security filter.
     */
    readonly query: pulumi.Output<string>;
    /**
     * The version of the security filter.
     */
    readonly version: pulumi.Output<number>;
    /**
     * Create a SecurityMonitoringFilter resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SecurityMonitoringFilterArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering SecurityMonitoringFilter resources.
 */
export interface SecurityMonitoringFilterState {
    /**
     * Exclusion filters to exclude some logs from the security filter.
     */
    exclusionFilters?: pulumi.Input<pulumi.Input<inputs.SecurityMonitoringFilterExclusionFilter>[]>;
    /**
     * The filtered data type. Valid values are `logs`.
     */
    filteredDataType?: pulumi.Input<string>;
    /**
     * Whether the security filter is enabled.
     */
    isEnabled?: pulumi.Input<boolean>;
    /**
     * The name of the security filter.
     */
    name?: pulumi.Input<string>;
    /**
     * The query of the security filter.
     */
    query?: pulumi.Input<string>;
    /**
     * The version of the security filter.
     */
    version?: pulumi.Input<number>;
}
/**
 * The set of arguments for constructing a SecurityMonitoringFilter resource.
 */
export interface SecurityMonitoringFilterArgs {
    /**
     * Exclusion filters to exclude some logs from the security filter.
     */
    exclusionFilters?: pulumi.Input<pulumi.Input<inputs.SecurityMonitoringFilterExclusionFilter>[]>;
    /**
     * The filtered data type. Valid values are `logs`.
     */
    filteredDataType?: pulumi.Input<string>;
    /**
     * Whether the security filter is enabled.
     */
    isEnabled: pulumi.Input<boolean>;
    /**
     * The name of the security filter.
     */
    name: pulumi.Input<string>;
    /**
     * The query of the security filter.
     */
    query: pulumi.Input<string>;
}
