import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Provides a Sensitive Data Scanner group resource.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const mygroup = new datadog.SensitiveDataScannerGroup("mygroup", {
 *     description: "A relevant description",
 *     filter: {
 *         query: "service:my-service",
 *     },
 *     isEnabled: true,
 *     name: "My new scanning group",
 *     productLists: ["apm"],
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 *  $ pulumi import datadog:index/sensitiveDataScannerGroup:SensitiveDataScannerGroup new_list ""
 * ```
 */
export declare class SensitiveDataScannerGroup extends pulumi.CustomResource {
    /**
     * Get an existing SensitiveDataScannerGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: SensitiveDataScannerGroupState, opts?: pulumi.CustomResourceOptions): SensitiveDataScannerGroup;
    /**
     * Returns true if the given object is an instance of SensitiveDataScannerGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SensitiveDataScannerGroup;
    /**
     * Description of the Datadog scanning group.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Filter object the scanning group applies.
     */
    readonly filter: pulumi.Output<outputs.SensitiveDataScannerGroupFilter>;
    /**
     * Whether or not the scanning group is enabled. If the group doesn't contain any rule or if all the rules in it are disabled, the group is force-disabled by our backend
     */
    readonly isEnabled: pulumi.Output<boolean>;
    /**
     * Name of the Datadog scanning group.
     */
    readonly name: pulumi.Output<string>;
    /**
     * List of products the scanning group applies.
     */
    readonly productLists: pulumi.Output<string[]>;
    /**
     * Create a SensitiveDataScannerGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SensitiveDataScannerGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering SensitiveDataScannerGroup resources.
 */
export interface SensitiveDataScannerGroupState {
    /**
     * Description of the Datadog scanning group.
     */
    description?: pulumi.Input<string>;
    /**
     * Filter object the scanning group applies.
     */
    filter?: pulumi.Input<inputs.SensitiveDataScannerGroupFilter>;
    /**
     * Whether or not the scanning group is enabled. If the group doesn't contain any rule or if all the rules in it are disabled, the group is force-disabled by our backend
     */
    isEnabled?: pulumi.Input<boolean>;
    /**
     * Name of the Datadog scanning group.
     */
    name?: pulumi.Input<string>;
    /**
     * List of products the scanning group applies.
     */
    productLists?: pulumi.Input<pulumi.Input<string>[]>;
}
/**
 * The set of arguments for constructing a SensitiveDataScannerGroup resource.
 */
export interface SensitiveDataScannerGroupArgs {
    /**
     * Description of the Datadog scanning group.
     */
    description?: pulumi.Input<string>;
    /**
     * Filter object the scanning group applies.
     */
    filter: pulumi.Input<inputs.SensitiveDataScannerGroupFilter>;
    /**
     * Whether or not the scanning group is enabled. If the group doesn't contain any rule or if all the rules in it are disabled, the group is force-disabled by our backend
     */
    isEnabled: pulumi.Input<boolean>;
    /**
     * Name of the Datadog scanning group.
     */
    name: pulumi.Input<string>;
    /**
     * List of products the scanning group applies.
     */
    productLists: pulumi.Input<pulumi.Input<string>[]>;
}
