import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Datadog service account resource. This can be used to create and manage Datadog service accounts.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const roRole = datadog.getRole({
 *     filter: "Datadog Read Only Role",
 * });
 * // Create a new Datadog service account
 * const bar = new datadog.ServiceAccount("bar", {
 *     email: "new@example.com",
 *     name: "Service Account Bar",
 *     roles: [roRole.then(roRole => roRole.id)],
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 *  $ pulumi import datadog:index/serviceAccount:ServiceAccount example_sa 6f1b44c0-30b2-11eb-86bc-279f7c1ebaa4
 * ```
 */
export declare class ServiceAccount extends pulumi.CustomResource {
    /**
     * Get an existing ServiceAccount resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ServiceAccountState, opts?: pulumi.CustomResourceOptions): ServiceAccount;
    /**
     * Returns true if the given object is an instance of ServiceAccount.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ServiceAccount;
    /**
     * Whether the service account is disabled.
     */
    readonly disabled: pulumi.Output<boolean | undefined>;
    /**
     * Email of the associated user.
     */
    readonly email: pulumi.Output<string>;
    /**
     * Name for the service account.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * A list a role IDs to assign to the service account.
     */
    readonly roles: pulumi.Output<string[] | undefined>;
    /**
     * Create a ServiceAccount resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ServiceAccountArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ServiceAccount resources.
 */
export interface ServiceAccountState {
    /**
     * Whether the service account is disabled.
     */
    disabled?: pulumi.Input<boolean>;
    /**
     * Email of the associated user.
     */
    email?: pulumi.Input<string>;
    /**
     * Name for the service account.
     */
    name?: pulumi.Input<string>;
    /**
     * A list a role IDs to assign to the service account.
     */
    roles?: pulumi.Input<pulumi.Input<string>[]>;
}
/**
 * The set of arguments for constructing a ServiceAccount resource.
 */
export interface ServiceAccountArgs {
    /**
     * Whether the service account is disabled.
     */
    disabled?: pulumi.Input<boolean>;
    /**
     * Email of the associated user.
     */
    email: pulumi.Input<string>;
    /**
     * Name for the service account.
     */
    name?: pulumi.Input<string>;
    /**
     * A list a role IDs to assign to the service account.
     */
    roles?: pulumi.Input<pulumi.Input<string>[]>;
}
