import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Datadog service definition resource. This can be used to create and manage Datadog service definitions in the service catalog using the YAML/JSON definition.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const serviceDefinition = new datadog.ServiceDefinitionYaml("serviceDefinition", {serviceDefinition: `schema-version: v2
 * dd-service: shopping-cart
 * team: E Commerce
 * contacts:
 *   - name: Support Email
 *     type: email
 *     contact: team@shopping.com
 *   - name: Support Slack
 *     type: slack
 *     contact: https://www.slack.com/archives/shopping-cart
 * repos:
 *   - name: shopping-cart source code
 *     provider: github
 *     url: http://github/shopping-cart
 * docs:
 *   - name: shopping-cart architecture
 *     provider: gdoc
 *     url: https://google.drive/shopping-cart-architecture
 *   - name: shopping-cart service Wiki
 *     provider: wiki
 *     url: https://wiki/shopping-cart
 * links:
 *   - name: shopping-cart runbook
 *     type: runbook
 *     url: https://runbook/shopping-cart
 * tags:
 *   - business-unit:retail
 *   - cost-center:engineering
 * integrations:
 *   pagerduty: https://www.pagerduty.com/service-directory/Pshopping-cart
 * extensions:
 *   datadoghq.com/shopping-cart:
 *     customField: customValue
 *
 * `});
 * ```
 *
 * ## Import
 *
 * ```sh
 *  $ pulumi import datadog:index/serviceDefinitionYaml:ServiceDefinitionYaml service_definition "<dd-service>"
 * ```
 */
export declare class ServiceDefinitionYaml extends pulumi.CustomResource {
    /**
     * Get an existing ServiceDefinitionYaml resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ServiceDefinitionYamlState, opts?: pulumi.CustomResourceOptions): ServiceDefinitionYaml;
    /**
     * Returns true if the given object is an instance of ServiceDefinitionYaml.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ServiceDefinitionYaml;
    /**
     * The YAML/JSON formatted definition of the service
     */
    readonly serviceDefinition: pulumi.Output<string>;
    /**
     * Create a ServiceDefinitionYaml resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ServiceDefinitionYamlArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ServiceDefinitionYaml resources.
 */
export interface ServiceDefinitionYamlState {
    /**
     * The YAML/JSON formatted definition of the service
     */
    serviceDefinition?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a ServiceDefinitionYaml resource.
 */
export interface ServiceDefinitionYamlArgs {
    /**
     * The YAML/JSON formatted definition of the service
     */
    serviceDefinition: pulumi.Input<string>;
}
