"use strict";
// *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
// *** Do not edit by hand unless you're certain you know what you are doing! ***
Object.defineProperty(exports, "__esModule", { value: true });
exports.ServiceLevelObjective = void 0;
const pulumi = require("@pulumi/pulumi");
const utilities = require("./utilities");
/**
 * Provides a Datadog service level objective resource. This can be used to create and manage Datadog service level objectives.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * // Metric-Based SLO
 * // Create a new Datadog service level objective
 * const foo = new datadog.ServiceLevelObjective("foo", {
 *     description: "My custom metric SLO",
 *     name: "Example Metric SLO",
 *     query: {
 *         denominator: "sum:my.custom.count.metric{*}.as_count()",
 *         numerator: "sum:my.custom.count.metric{type:good_events}.as_count()",
 *     },
 *     tags: [
 *         "foo:bar",
 *         "baz",
 *     ],
 *     targetThreshold: 99.9,
 *     thresholds: [
 *         {
 *             target: 99.9,
 *             timeframe: "7d",
 *             warning: 99.99,
 *         },
 *         {
 *             target: 99.9,
 *             timeframe: "30d",
 *             warning: 99.99,
 *         },
 *     ],
 *     timeframe: "30d",
 *     type: "metric",
 *     warningThreshold: 99.99,
 * });
 * // Monitor-Based SLO
 * // Create a new Datadog service level objective
 * const bar = new datadog.ServiceLevelObjective("bar", {
 *     description: "My custom monitor SLO",
 *     monitorIds: [
 *         1,
 *         2,
 *         3,
 *     ],
 *     name: "Example Monitor SLO",
 *     tags: [
 *         "foo:bar",
 *         "baz",
 *     ],
 *     targetThreshold: 99.9,
 *     thresholds: [
 *         {
 *             target: 99.9,
 *             timeframe: "7d",
 *             warning: 99.99,
 *         },
 *         {
 *             target: 99.9,
 *             timeframe: "30d",
 *             warning: 99.99,
 *         },
 *     ],
 *     timeframe: "30d",
 *     type: "monitor",
 *     warningThreshold: 99.99,
 * });
 * ```
 *
 * ## Import
 *
 * Service Level Objectives can be imported using their string ID, e.g.
 *
 * ```sh
 *  $ pulumi import datadog:index/serviceLevelObjective:ServiceLevelObjective baz 12345678901234567890123456789012
 * ```
 */
class ServiceLevelObjective extends pulumi.CustomResource {
    /**
     * Get an existing ServiceLevelObjective resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name, id, state, opts) {
        return new ServiceLevelObjective(name, state, Object.assign(Object.assign({}, opts), { id: id }));
    }
    /**
     * Returns true if the given object is an instance of ServiceLevelObjective.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj) {
        if (obj === undefined || obj === null) {
            return false;
        }
        return obj['__pulumiType'] === ServiceLevelObjective.__pulumiType;
    }
    constructor(name, argsOrState, opts) {
        let resourceInputs = {};
        opts = opts || {};
        if (opts.id) {
            const state = argsOrState;
            resourceInputs["description"] = state ? state.description : undefined;
            resourceInputs["forceDelete"] = state ? state.forceDelete : undefined;
            resourceInputs["groups"] = state ? state.groups : undefined;
            resourceInputs["monitorIds"] = state ? state.monitorIds : undefined;
            resourceInputs["name"] = state ? state.name : undefined;
            resourceInputs["query"] = state ? state.query : undefined;
            resourceInputs["tags"] = state ? state.tags : undefined;
            resourceInputs["targetThreshold"] = state ? state.targetThreshold : undefined;
            resourceInputs["thresholds"] = state ? state.thresholds : undefined;
            resourceInputs["timeframe"] = state ? state.timeframe : undefined;
            resourceInputs["type"] = state ? state.type : undefined;
            resourceInputs["validate"] = state ? state.validate : undefined;
            resourceInputs["warningThreshold"] = state ? state.warningThreshold : undefined;
        }
        else {
            const args = argsOrState;
            if ((!args || args.name === undefined) && !opts.urn) {
                throw new Error("Missing required property 'name'");
            }
            if ((!args || args.thresholds === undefined) && !opts.urn) {
                throw new Error("Missing required property 'thresholds'");
            }
            if ((!args || args.type === undefined) && !opts.urn) {
                throw new Error("Missing required property 'type'");
            }
            resourceInputs["description"] = args ? args.description : undefined;
            resourceInputs["forceDelete"] = args ? args.forceDelete : undefined;
            resourceInputs["groups"] = args ? args.groups : undefined;
            resourceInputs["monitorIds"] = args ? args.monitorIds : undefined;
            resourceInputs["name"] = args ? args.name : undefined;
            resourceInputs["query"] = args ? args.query : undefined;
            resourceInputs["tags"] = args ? args.tags : undefined;
            resourceInputs["targetThreshold"] = args ? args.targetThreshold : undefined;
            resourceInputs["thresholds"] = args ? args.thresholds : undefined;
            resourceInputs["timeframe"] = args ? args.timeframe : undefined;
            resourceInputs["type"] = args ? args.type : undefined;
            resourceInputs["validate"] = args ? args.validate : undefined;
            resourceInputs["warningThreshold"] = args ? args.warningThreshold : undefined;
        }
        opts = pulumi.mergeOptions(utilities.resourceOptsDefaults(), opts);
        super(ServiceLevelObjective.__pulumiType, name, resourceInputs, opts);
    }
}
exports.ServiceLevelObjective = ServiceLevelObjective;
/** @internal */
ServiceLevelObjective.__pulumiType = 'datadog:index/serviceLevelObjective:ServiceLevelObjective';
//# sourceMappingURL=serviceLevelObjective.js.map