import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
/**
 * Provides a Datadog synthetics private location resource. This can be used to create and manage Datadog synthetics private locations.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const privateLocation = new datadog.SyntheticsPrivateLocation("privateLocation", {
 *     description: "Description of the private location",
 *     name: "First private location",
 *     tags: [
 *         "foo:bar",
 *         "env:test",
 *     ],
 * });
 * ```
 *
 * ## Import
 *
 * Synthetics private locations can be imported using their string ID, e.g.
 *
 * ```sh
 *  $ pulumi import datadog:index/syntheticsPrivateLocation:SyntheticsPrivateLocation bar pl:private-location-name-abcdef123456
 * ```
 */
export declare class SyntheticsPrivateLocation extends pulumi.CustomResource {
    /**
     * Get an existing SyntheticsPrivateLocation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: SyntheticsPrivateLocationState, opts?: pulumi.CustomResourceOptions): SyntheticsPrivateLocation;
    /**
     * Returns true if the given object is an instance of SyntheticsPrivateLocation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SyntheticsPrivateLocation;
    /**
     * Configuration skeleton for the private location. See installation instructions of the private location on how to use this configuration.
     */
    readonly config: pulumi.Output<string>;
    /**
     * Description of the private location.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The private location metadata
     */
    readonly metadata: pulumi.Output<outputs.SyntheticsPrivateLocationMetadata | undefined>;
    /**
     * Synthetics private location name.
     */
    readonly name: pulumi.Output<string>;
    /**
     * A list of tags to associate with your synthetics private location.
     */
    readonly tags: pulumi.Output<string[] | undefined>;
    /**
     * Create a SyntheticsPrivateLocation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SyntheticsPrivateLocationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering SyntheticsPrivateLocation resources.
 */
export interface SyntheticsPrivateLocationState {
    /**
     * Configuration skeleton for the private location. See installation instructions of the private location on how to use this configuration.
     */
    config?: pulumi.Input<string>;
    /**
     * Description of the private location.
     */
    description?: pulumi.Input<string>;
    /**
     * The private location metadata
     */
    metadata?: pulumi.Input<inputs.SyntheticsPrivateLocationMetadata>;
    /**
     * Synthetics private location name.
     */
    name?: pulumi.Input<string>;
    /**
     * A list of tags to associate with your synthetics private location.
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
}
/**
 * The set of arguments for constructing a SyntheticsPrivateLocation resource.
 */
export interface SyntheticsPrivateLocationArgs {
    /**
     * Description of the private location.
     */
    description?: pulumi.Input<string>;
    /**
     * The private location metadata
     */
    metadata?: pulumi.Input<inputs.SyntheticsPrivateLocationMetadata>;
    /**
     * Synthetics private location name.
     */
    name: pulumi.Input<string>;
    /**
     * A list of tags to associate with your synthetics private location.
     */
    tags?: pulumi.Input<pulumi.Input<string>[]>;
}
