import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Datadog user resource. This can be used to create and manage Datadog users.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const roRole = datadog.getRole({
 *     filter: "Datadog Read Only Role",
 * });
 * // Create a new Datadog user
 * const foo = new datadog.User("foo", {
 *     email: "new@example.com",
 *     roles: [roRole.then(roRole => roRole.id)],
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 *  $ pulumi import datadog:index/user:User example_user 6f1b44c0-30b2-11eb-86bc-279f7c1ebaa4
 * ```
 */
export declare class User extends pulumi.CustomResource {
    /**
     * Get an existing User resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: UserState, opts?: pulumi.CustomResourceOptions): User;
    /**
     * Returns true if the given object is an instance of User.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is User;
    /**
     * Whether the user is disabled.
     */
    readonly disabled: pulumi.Output<boolean | undefined>;
    /**
     * Email address for user.
     */
    readonly email: pulumi.Output<string>;
    /**
     * Name for user.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * A list a role IDs to assign to the user.
     */
    readonly roles: pulumi.Output<string[] | undefined>;
    /**
     * Whether an invitation email should be sent when the user is created.
     */
    readonly sendUserInvitation: pulumi.Output<boolean | undefined>;
    /**
     * The ID of the user invitation that was sent when creating the user.
     */
    readonly userInvitationId: pulumi.Output<string>;
    /**
     * Returns `true` if the user is verified.
     */
    readonly verified: pulumi.Output<boolean>;
    /**
     * Create a User resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: UserArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering User resources.
 */
export interface UserState {
    /**
     * Whether the user is disabled.
     */
    disabled?: pulumi.Input<boolean>;
    /**
     * Email address for user.
     */
    email?: pulumi.Input<string>;
    /**
     * Name for user.
     */
    name?: pulumi.Input<string>;
    /**
     * A list a role IDs to assign to the user.
     */
    roles?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Whether an invitation email should be sent when the user is created.
     */
    sendUserInvitation?: pulumi.Input<boolean>;
    /**
     * The ID of the user invitation that was sent when creating the user.
     */
    userInvitationId?: pulumi.Input<string>;
    /**
     * Returns `true` if the user is verified.
     */
    verified?: pulumi.Input<boolean>;
}
/**
 * The set of arguments for constructing a User resource.
 */
export interface UserArgs {
    /**
     * Whether the user is disabled.
     */
    disabled?: pulumi.Input<boolean>;
    /**
     * Email address for user.
     */
    email: pulumi.Input<string>;
    /**
     * Name for user.
     */
    name?: pulumi.Input<string>;
    /**
     * A list a role IDs to assign to the user.
     */
    roles?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Whether an invitation email should be sent when the user is created.
     */
    sendUserInvitation?: pulumi.Input<boolean>;
}
