import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Datadog webhook resource. This can be used to create and manage Datadog webhooks.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * // Create a new Datadog webhook
 * const foo = new datadog.Webhook("foo", {
 *     name: "test-webhook",
 *     url: "example.com",
 *     encodeAs: "json",
 *     customHeaders: JSON.stringify({
 *         custom: "header",
 *     }),
 *     payload: JSON.stringify({
 *         custom: "payload",
 *     }),
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 *  $ pulumi import datadog:index/webhook:Webhook foo example-webhook
 * ```
 */
export declare class Webhook extends pulumi.CustomResource {
    /**
     * Get an existing Webhook resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: WebhookState, opts?: pulumi.CustomResourceOptions): Webhook;
    /**
     * Returns true if the given object is an instance of Webhook.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Webhook;
    /**
     * The headers attached to the webhook.
     */
    readonly customHeaders: pulumi.Output<string | undefined>;
    /**
     * Encoding type. Valid values are `json`, `form`.
     */
    readonly encodeAs: pulumi.Output<string>;
    /**
     * The name of the webhook. It corresponds with `<WEBHOOK_NAME>`.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The payload of the webhook.
     */
    readonly payload: pulumi.Output<string>;
    /**
     * The URL of the webhook.
     */
    readonly url: pulumi.Output<string>;
    /**
     * Create a Webhook resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: WebhookArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Webhook resources.
 */
export interface WebhookState {
    /**
     * The headers attached to the webhook.
     */
    customHeaders?: pulumi.Input<string>;
    /**
     * Encoding type. Valid values are `json`, `form`.
     */
    encodeAs?: pulumi.Input<string>;
    /**
     * The name of the webhook. It corresponds with `<WEBHOOK_NAME>`.
     */
    name?: pulumi.Input<string>;
    /**
     * The payload of the webhook.
     */
    payload?: pulumi.Input<string>;
    /**
     * The URL of the webhook.
     */
    url?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a Webhook resource.
 */
export interface WebhookArgs {
    /**
     * The headers attached to the webhook.
     */
    customHeaders?: pulumi.Input<string>;
    /**
     * Encoding type. Valid values are `json`, `form`.
     */
    encodeAs?: pulumi.Input<string>;
    /**
     * The name of the webhook. It corresponds with `<WEBHOOK_NAME>`.
     */
    name: pulumi.Input<string>;
    /**
     * The payload of the webhook.
     */
    payload?: pulumi.Input<string>;
    /**
     * The URL of the webhook.
     */
    url: pulumi.Input<string>;
}
