import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Datadog webhooks custom variable resource. This can be used to create and manage Datadog webhooks custom variables.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as datadog from "@pulumi/datadog";
 *
 * const foo = new datadog.WebhookCustomVariable("foo", {
 *     isSecret: true,
 *     name: "EXAMPLE_VARIABLE",
 *     value: "EXAMPLE-VALUE",
 * });
 * ```
 *
 * ## Import
 *
 * ```sh
 *  $ pulumi import datadog:index/webhookCustomVariable:WebhookCustomVariable foo EXAMPLE_VARIABLE
 * ```
 */
export declare class WebhookCustomVariable extends pulumi.CustomResource {
    /**
     * Get an existing WebhookCustomVariable resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: WebhookCustomVariableState, opts?: pulumi.CustomResourceOptions): WebhookCustomVariable;
    /**
     * Returns true if the given object is an instance of WebhookCustomVariable.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is WebhookCustomVariable;
    /**
     * Whether the custom variable is secret or not.
     */
    readonly isSecret: pulumi.Output<boolean>;
    /**
     * The name of the variable. It corresponds with `<CUSTOM_VARIABLE_NAME>`.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The value of the custom variable.
     */
    readonly value: pulumi.Output<string>;
    /**
     * Create a WebhookCustomVariable resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: WebhookCustomVariableArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering WebhookCustomVariable resources.
 */
export interface WebhookCustomVariableState {
    /**
     * Whether the custom variable is secret or not.
     */
    isSecret?: pulumi.Input<boolean>;
    /**
     * The name of the variable. It corresponds with `<CUSTOM_VARIABLE_NAME>`.
     */
    name?: pulumi.Input<string>;
    /**
     * The value of the custom variable.
     */
    value?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a WebhookCustomVariable resource.
 */
export interface WebhookCustomVariableArgs {
    /**
     * Whether the custom variable is secret or not.
     */
    isSecret: pulumi.Input<boolean>;
    /**
     * The name of the variable. It corresponds with `<CUSTOM_VARIABLE_NAME>`.
     */
    name: pulumi.Input<string>;
    /**
     * The value of the custom variable.
     */
    value: pulumi.Input<string>;
}
